<?php

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly
/**
 * Module Name: Gallery
 * Description: Display WP Gallery Images
 */

class TB_Gallery_Module extends Themify_Builder_Component_Module {

    function __construct() {
        parent::__construct(array(
            'name' => __('Gallery', 'themify'),
            'slug' => 'gallery'
        ));
    }

    public function get_options() {
        $is_img_enabled = Themify_Builder_Model::is_img_php_disabled();
        return array(
            array(
                'id' => 'mod_title_gallery',
                'type' => 'title'
            ),
            array(
                'id' => 'layout_gallery',
                'type' => 'radio',
                'label' => __('Gallery Layout', 'themify'),
                'options' => array(
		    array('value'=>'grid','name'=>__('Grid', 'themify')),
		    array('value'=>'showcase','name'=>__('Showcase', 'themify')),
		    array('value'=>'lightboxed','name'=>__('Lightboxed', 'themify')),
		    array('value'=>'slider','name'=>__('Slider', 'themify'))
                ),
	            'wrap_class' => 'tb_compact_radios',
                'option_js' => true
            ),
            array(
                'id' => 'layout_masonry',
                'type' => 'checkbox',
                'label' => '',
                'options' => array(
                    array('name' => 'masonry', 'value' => __('Use Masonry', 'themify'))
                ),
                'wrap_class' => 'tb_group_element_grid'
            ),
            array(
                'id' => 'thumbnail_gallery',
                'type' => 'image',
                'label' => __('Thumbnail', 'themify'),
                'class' => 'large',
                'wrap_class' => 'tb_group_element_lightboxed'
            ),
            array(
                'id' => 'shortcode_gallery',
                'type' => 'gallery',
                'label' => __('Gallery Shortcode', 'themify')
            ),
            array(
                'id' => 'gallery_pagination',
                'label' => __('Pagination', 'themify'),
		'type' => 'toggle_switch',
		'state' => array(
			'checkbox' => true,
			'on' => array('value'=>'pagination', 'text' =>__( 'Enable', 'themify' )),
			'off' => array('value'=>'', 'text' =>__( 'Disable', 'themify' )),
			'default' => 'off'
		),
		'binding' => array(
			'checked' => array(
				'show' => array('gallery_per_page')
			),
			'not_checked' => array(
				'hide' => array('gallery_per_page')
			)
		),
		'wrap_class' => 'tb_group_element_grid'
            ),
            array(
                'id' => 'gallery_per_page',
                'type' => 'text',
                'label' => __('Images Per Page', 'themify'),
                'wrap_class' => 'tb_group_element_grid tb-checkbox_element_pagination',
                'class' => 'xsmall'
            ),
            array(
                'id' => 'gallery_image_title',
                'label' => __('Image Title', 'themify'),
					'type' => 'toggle_switch',
					'state' => array(
						'checkbox' => true,
						'on' => array('value'=>'yes', 'text' =>__( 'Show', 'themify' )),
						'off' => array('value'=>'', 'text' =>__( 'Hide', 'themify' )),
						'default' => 'off'
					),
            ),
            array(
                'id' => 'gallery_exclude_caption',
                'label' => __('Image Caption', 'themify'),
					'type' => 'toggle_switch',
					'state' => array(
						'checkbox' => true,
						'on' => array('value'=>'', 'text' =>__( 'Show', 'themify' )),
						'off' => array('value'=>'yes', 'text' =>__( 'Hide', 'themify' )),
						'default' => 'on'
					),
            ),
            array(
                'id' => 's_image_w_gallery',
                'type' => 'text',
                'label' => __('Image Width', 'themify'),
                'class' => 'xsmall',
                'hide' => $is_img_enabled,
                'after' => 'px',
                'wrap_class' => 'tb_group_element_showcase tb_group_element_slider'
            ),
            array(
                'id' => 's_image_h_gallery',
                'type' => 'text',
                'label' => __('Image Height', 'themify'),
                'class' => 'xsmall',
                'hide' => $is_img_enabled,
                'after' => 'px',
                'wrap_class' => 'tb_group_element_showcase tb_group_element_slider'
            ),
            array(
                'id' => 's_image_size_gallery',
                'type' => 'select',
                'label' => __('Main Image Size', 'themify'),
                'hide' => !$is_img_enabled,
                'image_size' => true
            ),
            array(
                'id' => 'thumb_w_gallery',
                'type' => 'text',
                'label' => __('Thumbnail Width', 'themify'),
                'class' => 'xsmall',
                'hide' => $is_img_enabled,
                'after' => 'px'
            ),
            array(
                'id' => 'thumb_h_gallery',
                'type' => 'text',
                'label' => __('Thumbnail Height', 'themify'),
                'class' => 'xsmall',
                'hide' => $is_img_enabled,
                'after' => 'px'
            ),
            array(
                'id' => 'image_size_gallery',
                'type' => 'select',
                'label' => __('Image Size', 'themify'),
                'hide' => !$is_img_enabled,
                'image_size' => true
            ),
            array(
                'id' => 'gallery_columns',
                'type' => 'select',
                'label' => __('Columns', 'themify'),
                'options' => range(0, 9),
                'wrap_class' => 'tb_group_element_grid'
            ),
            array(
                'type' => 'slider',
                'label' => __('Slider Options', 'themify'),
                'options' => array(
                    array(
                        'id' => 'visible_opt_slider',
                        'type' => 'select',
                        'options' => array(2 => 2, 3 => 3, 4 => 4, 5 => 5, 6 => 6, 7 => 7),
                        'after' => __('Visible Thumbnails', 'themify')
                    ),
                    array(
                        'id' => 'mob_visible_opt_slider',
                        'type' => 'select',
                        'options' => array('',1, 2,3,4),
                        'after' => __('Mobile Visible Thumbnails', 'themify')
                    ),
                    array(
                        'id' => 'auto_scroll_opt_slider',
                        'type' => 'select',
                        'options' => array(
                            'off' => __('Off', 'themify'),
                            1 => __('1 sec', 'themify'),
                            2 => __('2 sec', 'themify'),
                            3 => __('3 sec', 'themify'),
                            4 => __('4 sec', 'themify'),
                            5 => __('5 sec', 'themify'),
                            6 => __('6 sec', 'themify'),
                            7 => __('7 sec', 'themify'),
                            8 => __('8 sec', 'themify'),
                            9 => __('9 sec', 'themify'),
                            10 => __('10 sec', 'themify'),
                            15 => __('15 sec', 'themify'),
                            20 => __('20 sec', 'themify')
                        ),
                        'after' => __('Auto Scroll', 'themify')
                    ),
                    array(
                        'id' => 'speed_opt_slider',
                        'type' => 'select',
                        'options' => array(
                            'normal' => __('Normal', 'themify'),
                            'fast' => __('Fast', 'themify'),
                            'slow' => __('Slow', 'themify')
                        ),
                        'after' => __('Speed', 'themify')
                    ),
                    array(
                        'id' => 'effect_slider',
                        'type' => 'select',
                        'options' => array(
                            'scroll' => __('Slide', 'themify'),
                            'fade' => __('Fade', 'themify'),
                            'crossfade' => __('Cross Fade', 'themify'),
                            'cover' => __('Cover', 'themify'),
                            'cover-fade' => __('Cover Fade', 'themify'),
                            'uncover' => __('Uncover', 'themify'),
                            'uncover-fade' => __('Uncover Fade', 'themify'),
                            'continuously' => __('Continuously', 'themify')
                        ),
                        'after' => __('Effect', 'themify')
                    ),
                    array(
                        'id' => 'pause_on_hover_slider',
							'type' => 'toggle_switch',
							'state' => array(
								'on' => array('value'=>'resume', 'text' =>__( 'Yes', 'themify' )),
								'off' => array('value'=>'false', 'text' =>__( 'No', 'themify' )),
								'default' => 'on'
                        ),
                        'after' => __('Pause On Hover', 'themify')
                    ),
                    array(
                        'id' => 'wrap_slider',
							'type' => 'toggle_switch',
							'state' => array(
								'on' => array('value'=>'yes', 'text' =>__( 'Yes', 'themify' )),
								'off' => array('value'=>'no', 'text' =>__( 'No', 'themify' )),
								'default' => 'on'
							),
			'after' => __('Wrap', 'themify')
                    ),
                    array(
                        'id' => 'show_arrow_slider',
							'type' => 'toggle_switch',
                        'after' => __('Show slider arrow buttons', 'themify'),
							'state' => array(
								'on' => array('value'=>'yes', 'text' =>__( 'Yes', 'themify' )),
								'off' => array('value'=>'no', 'text' =>__( 'No', 'themify' )),
								'default' => 'on'
							),
                        'binding' => array(
                            'no' => array(
                                'hide' => array('show_arrow_buttons_vertical')
                            ),
                            'select' => array(
                                'value' => 'no',
                                'show' => array('show_arrow_buttons_vertical')
                            )
                        )
                    ),
                    array(
                        'id' => 'show_arrow_buttons_vertical',
                        'type' => 'checkbox',
                        'options' => array(
                            array('name' => 'vertical', 'value' => __('Display arrow buttons vertical middle on the left/right side', 'themify'))
                        )
                    ),
                    array(
                        'id' => 'left_margin_slider',
                        'type' => 'text',
                        'class' => 'xsmall',
	                    'after' => __('Right margin (px)', 'themify')
                    ),
                    array(
                        'id' => 'right_margin_slider',
                        'type' => 'text',
                        'class' => 'xsmall',
                        'after' => __('Right margin (px)', 'themify')
                    )
                ),
                'wrap_class' => 'tb_group_element_slider'
            ),
            array(
                'id' => 'link_opt',
                'type' => 'select',
                'label' => __('Link to', 'themify'),
                'options' => array(
                    'post' => __('Attachment Page', 'themify'),
                    'file' => __('Media File', 'themify'),
                    'none' => __('None', 'themify')
                ),
                'wrap_class' => 'tb_group_element_grid tb_group_element_slider',
                'binding' => array(
                    'file' => array('show' => array('link_image_size')),
                    'post' => array('hide' => array('link_image_size')),
                    'none' => array('hide' => array('link_image_size'))
                )
            ),
            array(
                'id' => 'link_image_size',
                'type' => 'select',
                'label' => __('Link to Image Size', 'themify'),
                'image_size' => true,
                'wrap_class' => 'tb_group_element_grid tb_group_element_slider'
            ),
            array(
                'id' => 'appearance_gallery',
                'type' => 'checkbox',
                'label' => __('Image Appearance', 'themify'),
                'options' => array(
                    array('name' => 'rounded', 'value' => __('Rounded', 'themify')),
                    array('name' => 'drop-shadow', 'value' => __('Drop Shadow', 'themify')),
                    array('name' => 'bordered', 'value' => __('Bordered', 'themify')),
                    array('name' => 'circle', 'value' => __('Circle', 'themify'), 'help' => __('Circle style works better for square image ratio.', 'themify'))
                )
            ),
            array(
                'id' => 'css_gallery',
                'type' => 'custom_css'
            ),
            array('type'=>'custom_css_id')
        );
    }

    public function get_default_settings() {
        return array(
	    'auto_scroll_opt_slider'=>'4',
            'gallery_columns' => '4',
	    'visible_opt_slider'=>'4',
            'layout_gallery' => 'grid',
	    'link_image_size'=>'full',
	    'link_opt'=>'file',
            'thumb_w_gallery' => 300,
            'thumb_h_gallery' => 200
        );
    }

    public function get_visual_type() {
        return 'ajax';
    }

    public function get_styling() {
        $general = array(
            // Background
            self::get_expand('bg', array(
            self::get_tab(array(
                'n' => array(
                    'options' => array(
                        self::get_image()
                    )
                ),
                'h' => array(
                    'options' => array(
                         self::get_image('', 'b_i','bg_c','b_r','b_p', 'h')
                    )
                )
            ))
		)),
            // Font
            self::get_expand('f', array(
            self::get_tab(array(
                'n' => array(
                    'options' => array(
                        self::get_font_family(),
                        self::get_color_type(array(' .themify_image_title',' .themify_image_caption',' .gallery-showcase-title-text')),
                        self::get_font_size(),
                        self::get_line_height(' .gallery-caption'),
                        self::get_letter_spacing(),
                        self::get_text_align(' .gallery-caption'),
                        self::get_text_transform(),
                        self::get_font_style(),
                        self::get_text_decoration(' .gallery-caption', 'text_decoration_regular'),
			self::get_text_shadow(),
                    )
                ),
                'h' => array(
                    'options' => array(
                        self::get_font_family('', 'f_f', 'h'),
                        self::get_color_type(array(':hover .themify_image_title',':hover .themify_image_caption',':hover .gallery-showcase-title-text'),'','f_c_t_h', 'f_c_h', 'f_g_c_h'),
                        self::get_font_size('', 'f_s', '', 'h'),
                        self::get_line_height(' .gallery-caption', 'l_h', 'h'),
                        self::get_letter_spacing('', 'l_s', 'h'),
                        self::get_text_align(' .gallery-caption', 't_a', 'h'),
                        self::get_text_transform('', 't_t', 'h'),
                        self::get_font_style('', 'f_st', 'f_w', 'h'),
                        self::get_text_decoration(' .gallery-caption', 't_d_r', 'h'),
			self::get_text_shadow('','t_sh','h'),
                    )
                )
            ))
		)),
            // Link
            self::get_expand('l', array(
            self::get_tab(array(
                'n' => array(
                    'options' => array(
                        self::get_color(' a', 'link_color'),
                        self::get_text_decoration(' a')
                    )
                ),
                'h' => array(
                    'options' => array(
			self::get_color(' a', 'link_color',null, null, 'hover'),
                        self::get_text_decoration(' a', 't_d', 'h')
                    )
                )
            ))
		)),
            // Padding
            self::get_expand('p', array(
            self::get_tab(array(
                'n' => array(
                    'options' => array(
                        self::get_padding()
                    )
                ),
                'h' => array(
                    'options' => array(
                        self::get_padding('', 'p', 'h')
                    )
                )
            ))
		)),
            // Margin
            self::get_expand('m', array(
            self::get_tab(array(
                'n' => array(
                    'options' => array(
                        self::get_margin()
                    )
                ),
                'h' => array(
                    'options' => array(
                        self::get_margin('', 'm', 'h')
                    )
                )
            ))
		)),
            // Border
            self::get_expand('b', array(
            self::get_tab(array(
                'n' => array(
                    'options' => array(
                        self::get_border()
                    )
                ),
                'h' => array(
                    'options' => array(
                        self::get_border('', 'b', 'h')
                    )
                )
            ))
		)),
            // Filter
            self::get_expand('f_l', array(self::get_blend())),
				// Height & Min Height
				self::get_expand('ht', array(
						self::get_height(),
						self::get_min_height() )
				),
			// Rounded Corners
			self::get_expand('r_c', array(
					self::get_tab(array(
						'n' => array(
							'options' => array(
								self::get_border_radius()
							)
						),
						'h' => array(
							'options' => array(
								self::get_border_radius('', 'r_c', 'h')
							)
						)
					))
				)
			),
			// Shadow
			self::get_expand('sh', array(
					self::get_tab(array(
						'n' => array(
							'options' => array(
								self::get_box_shadow()
							)
						),
						'h' => array(
							'options' => array(
								self::get_box_shadow('', 'sh', 'h')
							)
						)
					))
				)
			),
        );

        return array(
            'type' => 'tabs',
            'options' => array(
                'g' => array(
                    'options' => $general
                ),
                'm_t' => array(
                    'options' => $this->module_title_custom_style()
                )
            )
        );
    }

    /**
     * Render plain content for static content.
     * 
     * @param array $module 
     * @return string
     */
    public function get_plain_content($module) {
        $mod_settings = wp_parse_args($module['mod_settings'], array(
            'mod_title_gallery' => '',
            'shortcode_gallery' => ''
        ));
        $text = '' !== $mod_settings['mod_title_gallery'] ? sprintf('<h3>%s</h3>', $mod_settings['mod_title_gallery']) : '';
        $text .= $mod_settings['shortcode_gallery'];
        return $text;
    }

}

///////////////////////////////////////
// Module Options
///////////////////////////////////////
Themify_Builder_Model::register_module('TB_Gallery_Module');
